This is the `v0.3.0` release of the `typinox` project.

In this version:

- Added support for `equinox` version `0.13`. Minor is bumped to reflect the potential breaking changes in upstream.
- Bumped dependency `beartype` to `0.22` to support potential Python `3.14`.
- Tweaked internal handling of `TypeVarTuple` to accommodate `beartype`'s current limitations.

<!-- TODO before release: pyproject.toml, docs/src/conf.py -->
